#!/usr/bin/python3
import gnupg
import os
import traceback
import subprocess
from uuid import getnode as get_mac
import json
import base64
import csv
import configparser
config = configparser.ConfigParser()
message = ' '
status = 'fail'

def createFolderIfnotExists(path):
    if not os.path.exists(path):
        os.makedirs(path, mode=0o777)

def get_mac_hash():
    mac = get_mac()
    return hash(mac)

def getBaseBoardSerialNumber():
    #sudo dmidecode -s baseboard-serial-number
    process1 = subprocess.check_output(["sudo",'dmidecode','-s','baseboard-serial-number']).decode("utf-8")
    dmiSerial =  process1.strip()
    if len(dmiSerial)==0 or dmiSerial == "None":
        #print "No Serial"
        process1 = subprocess.check_output(["sudo",'dmidecode','-s','system-uuid']).decode("utf-8")
        UUID = process1.strip()
        #print "UUID=",UUID
        dmiSerial=UUID.replace("-","")
        #print "dmidecode serial (baseboard)=",dmiSerial
    #else:
        #print "dmidecode serial(uuid)=",dmiSerial
    return (dmiSerial)

def recursiveFilePermissions(paths):
    os.system('sudo chmod -R 777 ' + paths)

recursiveFilePermissions('/home/sanuyi/gpguser/')
gpg = gnupg.GPG(gnupghome='/home/sanuyi/gpguser/') #Stores the encryption keys. change according to the home directory
pubkeys = gpg.list_keys()

if not pubkeys:
    input_data = gpg.gen_key_input(name_email='divya.testnasya@gmail.com',
    passphrase='pleasehideme',
    key_length=1024)
    key = gpg.gen_key(input_data)


def unpack(fileName):
    global message
    global status
    try:
        with open(fileName,'r') as f:
            encrypted_ascii_data = f.read()
        
        encrypted_string = str(encrypted_ascii_data)
    
        decrypted_data_obj = gpg.decrypt(encrypted_string, passphrase="pleasehideme")
        decrypted_data = str(decrypted_data_obj)
        if decrypted_data.strip() == '' or decrypted_data is None:
            message += "<br><strong> Couldn't decrypt file! </strong>"
            return status, message
        decrypted_json_data = json.loads(decrypted_data)
        
        system_id = decrypted_json_data["system_id"]
        
        if system_id == str(getBaseBoardSerialNumber()) and decrypted_data_obj.ok:
            message += " <br><strong> File Uploaded Successfully. </strong><br><strong>License: </strong>" + decrypted_json_data["license_key"]
            status = 'success'
            #saveKMIPClientFiles(decrypted_json_data,system_id)
            #saveCSVFile(decrypted_json_data)
        else:
            if system_id != str(getBaseBoardSerialNumber()):
                message += "<br><strong> System ID's did not match! </strong>"
            else:
                message += "<br><strong> File failed to be verified </strong>"
    except Exception as e:
        message += "<br> FAILED <br>" 
        message += str(traceback.format_exc()).replace('\n','<br>')

    return status, message
            
def saveKMIPClientFiles(decrypted_json_data,system_id):
    try:
        client_key_path = "/mnt/data/kmip_files/client/keys/"
        client_key_id_path = "/mnt/data/kmip_files/client/Id/"
        createFolderIfnotExists(client_key_path)
        createFolderIfnotExists(client_key_id_path)
        with open(client_key_path+"client_key_{}.pem".format(system_id), 'wb') as pem_file:
            pem_file.write(base64.b64decode(decrypted_json_data["client_key_{}.pem".format(system_id)]))

        with open(client_key_path+"client_certificate_{}.pem".format(system_id), 'wb') as pem_file:
            pem_file.write(base64.b64decode(decrypted_json_data["client_certificate_{}.pem".format(system_id)]))
        
        with open(client_key_path+"root_certificate_{}.pem".format(system_id), 'wb') as pem_file:
            pem_file.write(base64.b64decode(decrypted_json_data["root_certificate_{}.pem".format(system_id)]))
        
        with open(client_key_id_path+"key_id.txt", 'w') as pem_file:
            pem_file.write(decrypted_json_data["key_id"])
        
        config['client'] = decrypted_json_data["client"]
        config_path = "/etc/pykmip/"
        try:
            createFolderIfnotExists(config_path)
        except Exception as e:
            config_path = "/mnt/data/kmip_files/"

        with open(config_path+"pykmip.conf", 'w') as configfile:
            config.write(configfile)
    except Exception as e:
        print(e)

def saveCSVFile(data):
    csv_filename = "/mnt/data/licence/"
    createFolderIfnotExists(csv_filename)
    with open(csv_filename+"licenceFeature.csv", mode="w", newline="") as csv_file:
        csv_writer = csv.writer(csv_file)
        csv_writer.writerows(data["licenceFeatureData"])
    