# Creating Database

import sqlite3
conn=sqlite3.connect('sanuyiDB.db')
conn.execute('pragma foreign_keys=ON')
c=conn.cursor()

def create_table():
#1.SYSTEM TABLE
	c.execute(''' CREATE TABLE IF NOT EXISTS system
	(id INTEGER PRIMARY KEY,name TEXT ,state INT,
	cr_date TIMESTAMP,edit_date TIMESTAMP,del_date TIMESTAMP,location TEXT,
	total_vcpu INT,total_memoryGB INT,total_storageGB INT,used_vcpu INT,used_memoryGB INT,used_storageGB INT) ''')

#2.CONTROLLER TABLE
	c.execute('''CREATE TABLE IF NOT EXISTS controller(id INTEGER PRIMARY KEY,name TEXT ,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,system_id INT,
	location TEXT,'V_1.1V_1' INT,'V_1.1V_2' INT,'V_1.8V_1' INT,'V_1.8V_2' INT,'V_1.8V_3' INT,'V_3.3V' INT,'V_3.3V-SB' INT,
	'V_5V' INT,'V_5V_SB' INT,'V_12V' INT,'V_VCCP' INT,'V_VDDQ1' INT,'V_VDDQ2' INT,'V_VSA' INT,'V_VTT' INT,[default] INTEGER,low_threshold INTEGER,t_min INTEGER,hi_threshold INTEGER,t_max INTEGER,
	FOREIGN KEY(system_id) REFERENCES system(id)
	)
	''')

#3.PSU
	c.execute(''' CREATE TABLE IF NOT EXISTS psu
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT ,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,
	location TEXT,standard TEXT,connectors INT,ac_status INT,dc_status INT,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')
    
#4.FAN
	c.execute('''CREATE TABLE IF NOT EXISTS fan
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,
	location INT,size INT,speed INT,[default] INTEGER,low_threshold INTEGER,t_min INTEGER,hi_threshold INTEGER,connectors INT,temperature TEXT,t_max INTEGER,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')
    
#5.CPU
	c.execute('''CREATE TABLE IF NOT EXISTS cpu
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,location TEXT,
	cores INT,freq INT,watts INT,cache TEXT,bandwidth INT,socket_type INT,temperature TEXT,[default] INTEGER,low_threshold INTEGER,min INTEGER,hi_threshold INTEGER,max INTEGER,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')
    
#6.eth_ports
	c.execute('''CREATE TABLE IF NOT EXISTS eth_ports
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,location TEXT,
	ip TEXT,netmask TEXT,dhcp_enabled TEXT,port_id INT,enable_port TEXT,speed INT,tx_rx_default INTEGER,err_threshold INTEGER,err_max INTEGER,tx_rx_monitor INTEGER,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')

#7.GATEWAY
	c.execute('''CREATE TABLE IF NOT EXISTS gateway
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT ,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,location TEXT,default_gateway_ip TEXT,dns_server TEXT,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')

#8.TEMP_PROBES
	c.execute('''CREATE TABLE IF NOT EXISTS temp_probes
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INT,location TEXT,
	temp INT,[default] INTEGER,low_threshold INTEGER,t_min INTEGER,hi_threshold INTEGER,t_max INTEGER,status INT,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')

#9.DIMM
	c.execute('''CREATE TABLE IF NOT EXISTS dimm
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,controller_id INTEGER,location TEXT,
	size INT,watts INT,
	FOREIGN KEY(controller_id) REFERENCES controller(id))''')

#10.DISKS
	c.execute('''CREATE TABLE IF NOT EXISTS disks
	(id INTEGER PRIMARY KEY,system_name TEXT,name TEXT ,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,d_id TEXT,controller_id INT,location TEXT,
	type TEXT,size INT,interface TEXT,multi_device_id INT,
	vid VARCHAR(32),pid VARCHAR(32),prl VARCHAR(32),rev VARCHAR(32),serial TEXT ,wwn TEXT,tx_rx_default INTEGER,err_threshold INTEGER,
	err_max INTEGER,tx_rx_monitor INTEGER,temp INTEGER,[default] INTEGER,low_threshold INTEGER,t_min INTEGER,hi_threshold INTEGER,t_max INTEGER,
	temp_default INTEGER,
	FOREIGN KEY(controller_id) REFERENCES controller(id),
	FOREIGN KEY(multi_device_id) REFERENCES multi_device(id))''')

#11.MULTI_DEVICE
	c.execute('''CREATE TABLE IF NOT EXISTS multi_device
	(id INTEGER PRIMARY KEY,name TEXT,state INT,compression TEXT,acceleration TEXT,deduplication TEXT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,location TEXT,alt_location TEXT,system_name TEXT,level INT,pool_storage INT,
	tx_rx_default INTEGER,err_threshold INTEGER,err_max INTEGER,tx_rx_monitor INTEGER,acceleration_storage INT)''')

#12.VOLUME
	c.execute(''' CREATE TABLE IF NOT EXISTS volume
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,location TEXT,multi_device_id INT,
	size INT,compression TEXT,deduplication TEXT,												
	FOREIGN KEY(multi_device_id) REFERENCES multi_device(id) )''')

#21.vm_profile
	c.execute(''' CREATE TABLE IF NOT EXISTS vm_profile
	(id INTEGER PRIMARY KEY,name TEXT,vCPU INT,memory INT,storage INT) ''')
	#conn.commit()

#13.VM_Storage
	c.execute(''' CREATE TABLE IF NOT EXISTS vm_storage
	(id INTEGER PRIMARY KEY,name TEXT ,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,volume_id INT, vm_id INT,
	FOREIGN KEY(volume_id) REFERENCES volume(id),
	FOREIGN KEY(vm_id) REFERENCES virtualmachine(id) )''')

#14.VM_GROUP
	c.execute('''CREATE TABLE IF NOT EXISTS vm_group
	(id INTEGER PRIMARY KEY,group_name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,path_group_icon TEXT)''')
	
#15.VM_IMAGE

	c.execute(''' CREATE TABLE IF NOT EXISTS vm_image
	(id INTEGER PRIMARY KEY,image_name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP, path_app_saved TEXT,vm_image_size INT,vm_group_id INT,
	downloded TEXT,image_cost INT,support_cost INT,image_description TEXT,path_image_icon TEXT,
	app_download_server TEXT,image_type TEXT,file_name TEXT,download_percentage INT,uuid TEXT,profile_id INT,
	FOREIGN KEY(vm_group_id) REFERENCES vm_group(id),FOREIGN KEY(profile_id) REFERENCES vm_profile(id)) ''')


#16.VirtualMachine
	c.execute('''CREATE TABLE IF NOT EXISTS virtualmachine
	(id INTEGER PRIMARY KEY,name TEXT,type TEXT,parent_VM_id INT,state INT,cr_date TIMESTAMP,started_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,location TEXT,num_cores INT,
	memory_GB INT,saved_path TEXT,vm_disk_size INT,vm_image_id INT,
	last_local_backup TEXT,last_remote_backup TEXT,percentage INT,xml_path TEXT,
	FOREIGn KEY(vm_image_id) REFERENCES vm_image(id))''')


#17.vm_network
	c.execute('''CREATE TABLE IF NOT EXISTS vm_network
	(id INTEGER PRIMARY KEY,vm_id INT,veth_id INT,
	FOREIGN KEY(vm_id) REFERENCES virtualmachine(id),
	FOREIGN KEY(veth_id) REFERENCES veth_port(id)) ''')

#18.network
	c.execute('''CREATE TABLE IF NOT EXISTS network
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,cidr TEXT,enable_dhcp TEXT) ''')

#19.VETH_PORT
	c.execute('''CREATE TABLE IF NOT EXISTS veth_port
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,
	ip TEXT,netmask TEXT,network_id INT,
	FOREIGN KEY(network_id) REFERENCES network(id)) ''')

#20.StoragePath
	c.execute(''' CREATE TABLE IF NOT EXISTS storagepath
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,location TEXT,size INT,
	STORAGE_A TEXT,STORAGE_B TEXT)''')
	#conn.commit()



#22.logging
	c.execute(''' CREATE TABLE IF NOT EXISTS logging
	(id INTEGER PRIMARY KEY,name TEXT,log_state TEXT,log_level INT )''')
	#conn.commit()

#23 email-alerts
	c.execute('''CREATE TABLE IF NOT EXISTS email_logs
	(id INTEGER PRIMARY KEY,recipient_email TEXT,sender_email TEXT,password TEXT,cr_date TIMESTAMP,
	edit_date TIMESTAMP,del_date TIMESTAMP,smtp_server TEXT,port INT,
	alert_type TEXT)''')
	#conn.commit()

#24 Backup
	c.execute('''CREATE TABLE IF NOT EXISTS backup
	(id INTEGER PRIMARY KEY,destination_name TEXT,state INT,
	cr_date TIMESTAMP,edit_date TIMESTAMP,del_date TIMESTAMP,
	ip_address TEXT,account_name TEXT,password TEXT,certificate_path TEXT) ''')
	#conn.commit()


	

#26 BackupHistory
	c.execute('''CREATE TABLE IF NOT EXISTS myBackups
	(id INTEGER PRIMARY KEY,BackupName TEXT,uuid TEXT,
	cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	image_description TEXT,download_path TEXt,download_state TEXT,local_path TEXT,vm_type TEXT,
	VMId INT,vm_image_size INT,vm_group_id INT,vm_image_icon_path TEXT,
	image_cost INT,support_cost INT,state INT,profile_id INT,backup_time DATETIME,
	upload_state INT,download_percentage INT,BackupServerID INT,
	FOREIGN KEY(vm_group_id) REFERENCES vm_group(id),
	FOREIGN KEY(vm_type) REFERENCES virtualmachine(id),
	FOREIGN KEY(BackupServerID) REFERENCES backup(id),
	FOREIGN KEY(VMID) REFERENCES virtualmachine(id),
	FOREIGN KEY(profile_id) REFERENCES vm_profile(id)
	)''')

#28 Organisation
	c.execute(''' CREATE TABLE IF NOT EXISTS OrgGroup(
	id INTEGER PRIMARY KEY,state INT,name TEXT,description Text,hyperlink TEXT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,level INTEGER) ''')
	conn.commit()
	
#27 Person
	c.execute(''' CREATE TABLE IF NOT EXISTS Person
	(id INTEGER PRIMARY KEY,state INT,userName TEXT,FirstName TEXT,MiddleName TEXT,
	LastName TEXT,contactEmail TEXT,password TEXT,hyperlink TEXT,
	contactPhone INTEGER,cr_date TEXT,edit_date TEXT,del_date TEXT,login_time DATETIME,num_attempt INT,address1 TEXT,address2 TEXT,
	city TEXT,state_providence TEXT,country TEXT,postalcode INTEGER,manager_id INTEGER,employmentStatus TEXT,companyEmail TEXT,companyPhone INTEGER,profilePic_id INTEGER,
	FOREIGN KEY (profilePic_id) REFERENCES fileInfo(id),FOREIGN KEY(manager_id) REFERENCES person(id))''')
	conn.commit()


#29 OrgRole
	c.execute(''' CREATE TABLE IF NOT EXISTS OrgRole(
	id INTEGER PRIMARY KEY,name TEXT,description TEXT,hyperlink TEXT,state INT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME
	)''')

#30 PersonLink
	c.execute(''' CREATE TABLE IF NOT EXISTS UserLink(
	id INTEGER PRIMARY KEY,state INT,name TEXT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,person_id INTEGER,role_id INTEGER,group_id INTEGER,type TEXT,
	FOREIGN KEY(person_id) REFERENCES person(id),FOREIGN KEY(role_id) REFERENCES OrgRole(id),FOREIGN KEY(group_id) REFERENCES OrgGroup(id)
	)''')

#30 RoleLink
	c.execute(''' CREATE TABLE IF NOT EXISTS RoleLink(
	id INTEGER PRIMARY KEY,state INT,name TEXT,group_id INTEGER,role_id INTEGER,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	FOREIGN KEY(group_id) REFERENCES OrgGroup(id),FOREIGN KEY(role_id) REFERENCES OrgRole(id)
	
	)''')

# GroupLink
	c.execute('''CREATE TABLE IF NOT EXISTS GroupLink 
	(id INTEGER PRIMARY KEY,state INT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,link_group_id INT,group_id INT,
	FOREIGN KEY(link_group_id) REFERENCES OrgGroup(id),
	FOREIGN KEY(group_id) REFERENCES OrgGroup(id))''')

#31 app_link
	c.execute(''' CREATE TABLE IF NOT EXISTS app_link(
	id INTEGER PRIMARY KEY,state INT,group_id INTEGER,app_id INTEGER,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	FOREIGN KEY(group_id) REFERENCES OrgGroup(id),FOREIGN KEY(app_id) REFERENCES myBackups(id)
	
	)''')

#32 fileInfo
	c.execute(''' CREATE TABLE IF NOT EXISTS fileInfo(
	id INTEGER PRIMARY KEY,name TEXT,path TEXT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME
		
	)''')


#28 Protocol
	c.execute('''CREATE TABLE IF NOT EXISTS protocol
	(id INTEGER PRIMARY KEY,name TEXT,User INT,Password INT,iqn INT,wwn INT) ''')

#protocols
	c.execute(''' CREATE TABLE IF NOT EXISTS protocols
	(id INTEGER PRIMARY KEY,prot1 INT,prot2 INT,prot3 INT,prot4 INT,prot5 INT,prot6 INT,prot7 INT,prot8 INT,prot9 INT,prot10 INT,
	 FOREIGN KEY(prot1) REFERENCES protocol(id),
	 FOREIGN KEY(prot2) REFERENCES protocol(id),
	 FOREIGN KEY(prot3) REFERENCES protocol(id),
	 FOREIGN KEY(prot4) REFERENCES protocol(id),
	 FOREIGN KEY(prot5) REFERENCES protocol(id),
	 FOREIGN KEY(prot6) REFERENCES protocol(id),
	 FOREIGN KEY(prot7) REFERENCES protocol(id),
	 FOREIGN KEY(prot8) REFERENCES protocol(id),
	 FOREIGN KEY(prot9) REFERENCES protocol(id),
	 FOREIGN KEY(prot10) REFERENCES protocol(id)) ''')


#host
	c.execute('''CREATE TABLE IF NOT EXISTS host
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	user_name TEXT,iqn TEXT,wwn TEXT,pw TEXT,chap BOOLEAN,protocol INT)
	''')


#29 export
	c.execute('''CREATE TABLE IF NOT EXISTS export
    (id INTEGER PRIMARY KEY,state INT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,port_id INT,vol_id INT,host_id INT,lun INT,
    FOREIGN KEY(port_id) REFERENCES eth_ports(id),FOREIGN KEY(vol_id) REFERENCES volume(id),FOREIGN KEY(host_id) REFERENCES host(id))
    ''')

#volume_snapshot
	c.execute(''' CREATE TABLE IF NOT EXISTS volume_snapshot
	(id INTEGER PRIMARY KEY,name TEXT,state INT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	vol_id INT,FOREIGN KEY(vol_id) REFERENCES volume(id))
	''')

#volume_backup
	c.execute(''' CREATE TABLE IF NOT EXISTS volume_backup
	(id INTEGER PRIMARY KEY,name TEXT,cr_date DATETIME,edit_date DATETIME,del_date DATETIME,
	vol_id INT,dest_vol INT,FOREIGN KEY(vol_id) REFERENCES volume(id),
	FOREIGN KEY(dest_vol) REFERENCES volume_snapshot(id) ) ''')

#25 SCHEDULE
	c.execute('''CREATE TABLE IF NOT EXISTS schedule
	(id INTEGER PRIMARY KEY,name TEXT,frequency TEXT,start_time TEXT,start_date TEXT,end_date TEXT,
	action TEXT,action_element TEXT,status TEXT,vm_ID INT,isDeleted BOOLEAN,t_next TEXT,done_percentage INT,vol_id INT,
	FOREIGN KEY(vm_ID) REFERENCES virtualmachine(id),FOREIGN KEY(vol_id) REFERENCES volume(id)) ''')

# schedule history
	c.execute(''' CREATE TABLE IF NOT EXISTS schedule_history
	(id INTEGER PRIMARY KEY,schedule_id INT,complete_date DATETIME,complete_time DATETIME,result TEXT,
	FOREIGN KEY(schedule_id) REFERENCES schedule(id)) ''')

	
	conn.commit()
	c.close()
	conn.close()

create_table()


